<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES" sourcelanguage="en_US">
<context>
    <name>AlbumDefaultPage</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="35"/>
        <source>Add Songs</source>
        <translation>añadir cancións</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="43"/>
        <source>Open Folders</source>
        <translation>abrir carpetas</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="59"/>
        <source>Drag music files here or</source>
        <translation>arrastre os ficheiros de música aquí ou</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="63"/>
        <source> scan the Music directory</source>
        <translation>escanea o directorio de música</translation>
    </message>
</context>
<context>
    <name>AlbumGridDelegate</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumGridDelegate.qml" line="116"/>
        <source>1 song</source>
        <translation>1 canción</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumGridDelegate.qml" line="116"/>
        <source>%1 songs</source>
        <translation>%1 cancións</translation>
    </message>
</context>
<context>
    <name>AlbumListDelegate</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListDelegate.qml" line="107"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListView.qml" line="33"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListView.qml" line="38"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListView.qml" line="43"/>
        <source>Tracks</source>
        <translation>Pistas</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListView.qml" line="48"/>
        <source>Date added</source>
        <translation>Data de adición</translation>
    </message>
</context>
<context>
    <name>AlbumMoreMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/AlbumMoreMenu.qml" line="20"/>
        <source>View details</source>
        <translation>Ver detalles</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/AlbumMoreMenu.qml" line="28"/>
        <source>Play all</source>
        <translation>Reproducir todo</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/AlbumMoreMenu.qml" line="37"/>
        <source>Add to</source>
        <translation>Engadir a</translation>
    </message>
</context>
<context>
    <name>AlbumSublist</name>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublist.qml" line="36"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublist.qml" line="41"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublist.qml" line="46"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
</context>
<context>
    <name>AlbumSublistDelegate</name>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublistDelegate.qml" line="147"/>
        <source>My Favorites</source>
        <translation>Os meus favoritos</translation>
    </message>
</context>
<context>
    <name>AlbumSublistView</name>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublistView.qml" line="55"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublistView.qml" line="60"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublistView.qml" line="66"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumView.qml" line="54"/>
        <source>Albums</source>
        <translation>Álbums</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumView.qml" line="55"/>
        <source>%1 albums - %2 songs</source>
        <translation>%1 álbums - %2 cancións</translation>
    </message>
</context>
<context>
    <name>AllMusicDefaultPage</name>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="42"/>
        <source>Add Songs</source>
        <translation>añadir cancións</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="50"/>
        <source>Open Folders</source>
        <translation>abrir carpetas</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="65"/>
        <source>Drag music files here or</source>
        <translation>arrastre os ficheiros de música aquí ou</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="99"/>
        <source>Your favorite songs will be displayed here</source>
        <translation>As cancións favoritas mostraranse aquí</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="111"/>
        <source>Click “</source>
        <translation>Preme “</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="122"/>
        <source>” to add a song to My Favorites</source>
        <translation>” para engadir unha canción aos Meus Favoritos</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="157"/>
        <source>No songs yet. Click “</source>
        <translation>Non hai cancións. Preme “</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="168"/>
        <source>” to add songs to the playlist</source>
        <translation>” para engadir cancións á lista de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="69"/>
        <source> scan the Music directory</source>
        <translation>escanea o directorio de música</translation>
    </message>
</context>
<context>
    <name>AllMusicList</name>
    <message>
        <location filename="../src/music-player/musicList/AllMusicList.qml" line="17"/>
        <source>All Songs</source>
        <translation>Todas as cancións</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicList.qml" line="30"/>
        <source>1 song</source>
        <translation>1 canción</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicList.qml" line="30"/>
        <source>%1 songs</source>
        <translation>%1 cancións</translation>
    </message>
</context>
<context>
    <name>AllMusicListDelegate</name>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListDelegate.qml" line="212"/>
        <source>My Favorites</source>
        <translation>Os meus favoritos</translation>
    </message>
</context>
<context>
    <name>AllMusicListView</name>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListView.qml" line="38"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListView.qml" line="44"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListView.qml" line="49"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListView.qml" line="54"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
</context>
<context>
    <name>ArtistDefaultPage</name>
    <message>
        <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="36"/>
        <source>Add Songs</source>
        <translation>añadir cancións</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="44"/>
        <source>Open Folders</source>
        <translation>abrir carpetas</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="60"/>
        <source>Drag music files here or</source>
        <translation>arrastre os ficheiros de música aquí ou</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="64"/>
        <source> scan the Music directory</source>
        <translation>escanea o directorio de música</translation>
    </message>
</context>
<context>
    <name>ArtistGridDelegate</name>
    <message>
        <location filename="../src/music-player/singerlist/ArtistGridDelegate.qml" line="149"/>
        <source>1 song</source>
        <translation>1 canción</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistGridDelegate.qml" line="149"/>
        <source>%1 songs</source>
        <translation>%1 cancións</translation>
    </message>
</context>
<context>
    <name>ArtistMoreMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/ArtistMoreMenu.qml" line="18"/>
        <source>View details</source>
        <translation>Ver detalles</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ArtistMoreMenu.qml" line="26"/>
        <source>Play all</source>
        <translation>Reproducir todo</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ArtistMoreMenu.qml" line="35"/>
        <source>Add to</source>
        <translation>Engadir a</translation>
    </message>
</context>
<context>
    <name>ArtistSublistDelegate</name>
    <message>
        <location filename="../src/music-player/musicsublist/ArtistSublistDelegate.qml" line="102"/>
        <source>My Favorites</source>
        <translation>Os meus favoritos</translation>
    </message>
</context>
<context>
    <name>ArtistSublistView</name>
    <message>
        <location filename="../src/music-player/musicsublist/ArtistSublistView.qml" line="59"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/ArtistSublistView.qml" line="65"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/ArtistSublistView.qml" line="70"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
</context>
<context>
    <name>ArtistView</name>
    <message>
        <location filename="../src/music-player/singerlist/ArtistView.qml" line="54"/>
        <source>Artists</source>
        <translation>Artistas</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistView.qml" line="55"/>
        <source>%1 artists - %2 songs</source>
        <translation>%1 artistas - %2 cancións</translation>
    </message>
</context>
<context>
    <name>CDRemovedDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/CDRemovedDialog.qml" line="32"/>
        <source>The CD has been removed</source>
        <translation>Expulsouse o CD</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CDRemovedDialog.qml" line="36"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>CloseConfirmDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="36"/>
        <source>Please choose your action</source>
        <translation>Por favor, selecciona a túa operación</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="50"/>
        <source>Minimize to system tray</source>
        <translation>Minimizar na bandexa</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="62"/>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="73"/>
        <source>Do not ask again</source>
        <translation>Non preguntar de novo</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="90"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="98"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>CurrentPlayList</name>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayList.qml" line="97"/>
        <source>Play queue</source>
        <translation>Reproducir cola</translation>
    </message>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayList.qml" line="114"/>
        <source>1 song</source>
        <translation>1 canción</translation>
    </message>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayList.qml" line="114"/>
        <source>%1 songs</source>
        <translation>%1 cancións</translation>
    </message>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayList.qml" line="128"/>
        <source>Empty</source>
        <translation>Baleirar</translation>
    </message>
</context>
<context>
    <name>CurrentPlayListDelegate</name>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayListDelegate.qml" line="123"/>
        <source>My Favorites</source>
        <translation>Os meus favoritos</translation>
    </message>
</context>
<context>
    <name>CustomPlaylistModel</name>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/CustomPlaylistModel.qml" line="23"/>
        <source>My Favorites</source>
        <translation>Os meus favoritos</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/CustomPlaylistModel.qml" line="80"/>
        <source>CD playlist</source>
        <translation>Lista de reproducción de CD</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/CustomPlaylistModel.qml" line="86"/>
        <source>CD</source>
        <translation>CD</translation>
    </message>
</context>
<context>
    <name>DeleteLocalDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="34"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Estás seguro de que queres eliminar %1?</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="36"/>
        <source>Are you sure you want to delete the selected %1 songs?</source>
        <translation>Tes a certeza de querer eliminar as %1 cancións seleccionadas?</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="45"/>
        <source>The song files contained will also be deleted</source>
        <translation>As cancións contidas contidas tamén serán eliminadas</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="53"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="65"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DeleteSonglistDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="41"/>
        <source>Are you sure you want to remove %1?</source>
        <translation>Estás seguro de que quere eliminar %1?</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="43"/>
        <source>Are you sure you want to remove the selected %1 songs?</source>
        <translation>Tes a certeza de querer eliminar as %1 cancións seleccionadas?</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="45"/>
        <source>Are you sure you want to delete this playlist?</source>
        <translation>Estás seguro de que quere eliminar esta lista de reprodución?</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="55"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="55"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="70"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>EqualizerDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="14"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="15"/>
        <source>Monophony</source>
        <translation>Monófono</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="16"/>
        <source>Classical</source>
        <translation>Clásica</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="17"/>
        <source>Club</source>
        <translation>Club</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="18"/>
        <source>Dance</source>
        <translation>Dance</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="19"/>
        <source>Full Bass</source>
        <translation>Baixo completo</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="20"/>
        <source>Full Bass and Treble</source>
        <translation>Baixo e agudos completos</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="21"/>
        <source>Full Treble</source>
        <translation>Agudo completo</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="22"/>
        <source>Headphones</source>
        <translation>Auriculares</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="23"/>
        <source>Hall</source>
        <translation>Vestíbulo</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="24"/>
        <source>Live</source>
        <translation>En directo</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="25"/>
        <source>Party</source>
        <translation>Festa</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="26"/>
        <source>Pop</source>
        <translation>Pop</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="27"/>
        <source>Reggae</source>
        <translation>Reggae</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="28"/>
        <source>Rock</source>
        <translation>Rock</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="29"/>
        <source>Ska</source>
        <translation>Ska</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="30"/>
        <source>Soft</source>
        <translation>Suave</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="31"/>
        <source>Soft Rock</source>
        <translation>Rock suave</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="32"/>
        <source>Techno</source>
        <translation>Tecno</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="106"/>
        <source>Equalizer</source>
        <translation>Ecualizador</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="182"/>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="205"/>
        <source>Reset</source>
        <translation>Restabelecer</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="314"/>
        <source>Preamplifier</source>
        <translation>Preamplificador</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/FileDialog.qml" line="15"/>
        <source>All Music</source>
        <translation>Toda a música</translation>
    </message>
</context>
<context>
    <name>ImportFailedDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/ImportFailedDialog.qml" line="32"/>
        <source>Import failed, no valid music file found</source>
        <translation>Fallou a importación e non se atopou ningún ficheiro de música válido</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/ImportFailedDialog.qml" line="36"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>ImportMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="25"/>
        <source>Play queue</source>
        <translation>Reproducir cola</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="40"/>
        <source>My favorites</source>
        <translation>Os meus favoritos</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="49"/>
        <source>Create new playlist</source>
        <translation>Crear nova lista de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="52"/>
        <source>New playlist</source>
        <translation>Nova lista de reprodución</translation>
    </message>
</context>
<context>
    <name>LyricPage</name>
    <message>
        <location filename="../src/music-player/lyric/LyricPage.qml" line="133"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../src/music-player/lyric/LyricPage.qml" line="141"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../src/music-player/lyric/LyricPage.qml" line="179"/>
        <source>No lyrics found</source>
        <translation>Non se atoparon letras</translation>
    </message>
    <message>
        <location filename="../src/music-player/lyric/LyricPage.qml" line="189"/>
        <source>Please put the lyric file (same name as the song) and the song file in the same folder</source>
        <translation>Coloca o ficheiro de letras (nome igual ao da canción) e o ficheiro da canción na mesma carpeta</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="188"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="203"/>
        <source>Play/Pause</source>
        <translation>Rep./Pausar</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="207"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="218"/>
        <source>Next</source>
        <translation>Seguinte</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="229"/>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="343"/>
        <source>Already added to the playlist</source>
        <translation>Xa está engadida á miña lista de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="346"/>
        <source>Added to &quot;%1&quot;</source>
        <translation>Engadido a &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="349"/>
        <source>Removed from &quot;My Favorites&quot;</source>
        <translation>Eliminado de &quot;Os Meus Favoritos&quot;</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="352"/>
        <source>A disc is connected</source>
        <translation>Hai un disco conectado</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="368"/>
        <source>My Favorites</source>
        <translation>Os meus favoritos</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="390"/>
        <source>All Songs</source>
        <translation>Todas as Cancións</translation>
    </message>
</context>
<context>
    <name>MulitSelectMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/MulitSelectMenu.qml" line="19"/>
        <source>Add to</source>
        <translation>Engadir a</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MulitSelectMenu.qml" line="28"/>
        <source>Remove from playlist</source>
        <translation>Eliminar da lista de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MulitSelectMenu.qml" line="28"/>
        <source>Remove from play queue</source>
        <translation>Eliminar da lista de reproducción</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MulitSelectMenu.qml" line="35"/>
        <source>Delete from local disk</source>
        <translation>Eliminar do disco local</translation>
    </message>
</context>
<context>
    <name>MusicBaselistview</name>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="36"/>
        <source>Library</source>
        <translation>Biblioteca</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="40"/>
        <source>Albums</source>
        <translation>Álbums</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="41"/>
        <source>Artists</source>
        <translation>Artistas</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="42"/>
        <source>All Songs</source>
        <translation>Todas as Cancións</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="47"/>
        <source>Playlists</source>
        <translation>Listas de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="64"/>
        <source>Create playlist</source>
        <translation>Crear lista de reproducción</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="66"/>
        <source>New playlist</source>
        <translation>Nova lista de reprodución</translation>
    </message>
</context>
<context>
    <name>MusicContentWindow</name>
    <message>
        <location filename="../src/music-player/mainwindow/MusicContentWindow.qml" line="22"/>
        <source>My Favorites</source>
        <translation>Os meus favoritos</translation>
    </message>
</context>
<context>
    <name>MusicInfoDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="71"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="80"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="86"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="95"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="101"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="107"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="114"/>
        <source>Path</source>
        <translation>Ruta</translation>
    </message>
</context>
<context>
    <name>MusicMoreMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="24"/>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="24"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="44"/>
        <source>Add to</source>
        <translation>Engadir a</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="52"/>
        <source>Open in file manager</source>
        <translation>Abrir no xestor de ficheiros</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="62"/>
        <source>Remove from playlist</source>
        <translation>Eliminar da lista de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="62"/>
        <source>Remove from play queue</source>
        <translation>Eliminar da lista de reproducción</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="72"/>
        <source>Delete from local disk</source>
        <translation>Eliminar do disco local</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="79"/>
        <source>Encoding</source>
        <translation>Codificación</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="104"/>
        <source>Song info</source>
        <translation>Información da canción</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/music-player/main.cpp" line="131"/>
        <source>Music is a local music player with beautiful design and simple functions.</source>
        <translation>A música é un reprodutor de música local cun fermoso deseño e funcións sinxelas.</translation>
    </message>
    <message>
        <location filename="../src/music-player/main.cpp" line="133"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../src/music-player/main.cpp" line="143"/>
        <source>Unknown album</source>
        <translation>Álbum descoñecido</translation>
    </message>
    <message>
        <location filename="../src/music-player/main.cpp" line="143"/>
        <source>Unknown artist</source>
        <translation>Artista descoñecido</translation>
    </message>
</context>
<context>
    <name>SearchResultDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/SearchResultDialog.qml" line="27"/>
        <source>Songs</source>
        <translation>Cancións</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SearchResultDialog.qml" line="39"/>
        <source>Artists</source>
        <translation>Artistas</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SearchResultDialog.qml" line="50"/>
        <source>Albums</source>
        <translation>Álbums</translation>
    </message>
</context>
<context>
    <name>SearchResultWindow</name>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="55"/>
        <source>No search results</source>
        <translation>Sen resultados</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="95"/>
        <source>Search Results</source>
        <translation>Pescudar resultados</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="100"/>
        <source>%1 albums - %2 songs</source>
        <translation>%1 álbums - %2 cancións</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="101"/>
        <source>1 album - 1 song</source>
        <translation>1 álbum - 1 canción</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="101"/>
        <source>%1 album - %2 songs</source>
        <translation>%1 álbum - %2 cancións</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="120"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="128"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="124"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="30"/>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="34"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="42"/>
        <source>Autoplay</source>
        <translation>Reproducir Auto.</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="53"/>
        <source>Remember playback position on exit</source>
        <translation>Recordar a posición de reproducción ao saír</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="66"/>
        <source>Enable fade in/out</source>
        <translation>Activar desaparecer</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="78"/>
        <source>Close Main Window</source>
        <translation>Pechar a Xanela Principal</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="91"/>
        <source>Minimize to system tray</source>
        <translation>Minimizar na bandexa</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="98"/>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="105"/>
        <source>Ask me always</source>
        <translation>Pregúnteme sempre</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="137"/>
        <source>Shortcuts</source>
        <translation>Atallos</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="158"/>
        <source>Play/Pause</source>
        <translation>Rep./Pausar</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="201"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="245"/>
        <source>Next</source>
        <translation>Seguinte</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="290"/>
        <source>Volume up</source>
        <translation>Subir o volume</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="335"/>
        <source>Volume down</source>
        <translation>Baixar o volume</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="379"/>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="501"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="534"/>
        <source>Replace</source>
        <translation>Substituír</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="490"/>
        <source>This shortcut key conflicts with [%1], click Replace to make this shortcut key take effect immediately</source>
        <translation>A tecla de atalho conflita con [%1], clica en Substituir para que esta tecla de atalho teña efecto inmediatamente</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="55"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="56"/>
        <source>Songs</source>
        <translation>Cancións</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="57"/>
        <source>Playlists</source>
        <translation>Listas de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="58"/>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="65"/>
        <source>Play/Pause</source>
        <translation>Rep./Pausar</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="66"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="67"/>
        <source>Next</source>
        <translation>Seguinte</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="68"/>
        <source>Volume Up</source>
        <translation>Subir volume</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="69"/>
        <source>Volume Down</source>
        <translation>Baixar volume</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="70"/>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="73"/>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="74"/>
        <source>Unfavorite</source>
        <translation>Non favorito</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="75"/>
        <source>Song info</source>
        <translation>Información da canción</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="78"/>
        <source>New playlist</source>
        <translation>Nova lista de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="79"/>
        <source>Add music</source>
        <translation>Engadir música</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="80"/>
        <source>Rename playlist</source>
        <translation>Renomear a lista de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="81"/>
        <source>Remove from playlist</source>
        <translation>Eliminar da lista de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="84"/>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="85"/>
        <source>Display shortcuts</source>
        <translation>Amosar atallos</translation>
    </message>
</context>
<context>
    <name>Shortcuts</name>
    <message>
        <location filename="../src/music-player/allItems/Shortcuts.qml" line="51"/>
        <source>New playlist</source>
        <translation>Nova lista de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/Shortcuts.qml" line="120"/>
        <source>My Favorites</source>
        <translation>Os meus favoritos</translation>
    </message>
</context>
<context>
    <name>SidebarMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="22"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="29"/>
        <source>Add songs</source>
        <translation>Engadir cancións</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="38"/>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="52"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>SortMenu</name>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="29"/>
        <source>CD playlist</source>
        <translation>Lista de reproducción de CD</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="33"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="34"/>
        <source>Date added</source>
        <translation>Data de adición</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="37"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="36"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="35"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
</context>
<context>
    <name>SublistTitleButton</name>
    <message>
        <location filename="../src/music-player/allItems/SublistTitleButton.qml" line="54"/>
        <source>1 song</source>
        <translation>1 canción</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SublistTitleButton.qml" line="54"/>
        <source>%1 songs</source>
        <translation>%1 cancións</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SublistTitleButton.qml" line="64"/>
        <source>Play All</source>
        <translation>Reproducir todo</translation>
    </message>
</context>
<context>
    <name>ToolButtonItem</name>
    <message>
        <location filename="../src/music-player/allItems/ToolButtonItem.qml" line="59"/>
        <source>Play All</source>
        <translation>Reproducir todo</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="43"/>
        <source>Sequential play</source>
        <translation>Reproducción secuencial</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="43"/>
        <source>List loop</source>
        <translation>Lista en bucle</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="43"/>
        <source>Single loop</source>
        <translation>Bucle único</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="43"/>
        <source>Shuffle</source>
        <translation>Modo ao Chou</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="207"/>
        <source>Unfavorite</source>
        <translation>Non favorito</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="207"/>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="220"/>
        <source>My Favorites</source>
        <translation>Os meus favoritos</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="238"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="259"/>
        <source>Play/Pause</source>
        <translation>Rep./Pausar</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="280"/>
        <source>Next</source>
        <translation>Seguinte</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="389"/>
        <source>Lyrics</source>
        <translation>Letras</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="438"/>
        <source>Play Queue</source>
        <translation>Reproducir cola</translation>
    </message>
</context>
<context>
    <name>WindowTitlebar</name>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="56"/>
        <source>Add playlist</source>
        <translation>Engadir lista de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="58"/>
        <source>New playlist</source>
        <translation>Nova lista de reprodución</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="63"/>
        <source>Add music</source>
        <translation>Engadir música</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="71"/>
        <source>Equalizer</source>
        <translation>Ecualizador</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="82"/>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="96"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="98"/>
        <source>Music is a local music player with beautiful design and simple functions.</source>
        <translation>A música é un reprodutor de música local cun fermoso deseño e funcións sinxelas.</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="99"/>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="213"/>
        <source>Previous page</source>
        <translation>Páxina anterior</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="229"/>
        <source>Next page</source>
        <translation>Páxina seguinte</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="239"/>
        <source>Search</source>
        <translation>Procurar</translation>
    </message>
</context>
</TS>
